======================
Overview
======================

This section contains the PyMedPhys :doc:`Release Notes<../release-notes>`,
along with with additional documentation that may be of interest to any
PyMedPhys visitor.

- :doc:`Release Notes<../release-notes>`
- :doc:`File Structure<file-structure>`
- :doc:`Benefits of Open Source<open-source-benefits>`
